package com.ozs.web.controller.accountmanagment;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ozs.common.core.controller.BaseController;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.utils.StringUtils;
import com.ozs.common.utils.file.FileUtils;
import com.ozs.common.utils.poi.ExcelUtil;
import com.ozs.service.entity.BaseRailwayManagement;
import com.ozs.service.entity.vo.BaseRailwayManagementVo;
import com.ozs.service.service.BaseRailwayManagementService;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.InputStream;
import java.util.List;

/**
 * <p>
 * 线路管理表前端控制器
 * </p>
 *
 * @author ozs
 * @since 2023-02-17
 */
@RestController
@RequestMapping("/service/baseRailwayManagement")
@Slf4j
public class BaseRailwayManagementController extends BaseController {
    @Resource
    BaseRailwayManagementService baseRailwayManagementService;

    /**
     * 线路管理表分页
     *
     * @param baseRailwayManagementVo
     * @return
     */
    @ApiOperation(value = "线路管理表分页")
    @PostMapping("/list")
    public AjaxResult selectBaseLineManagement(@RequestBody BaseRailwayManagementVo baseRailwayManagementVo) {
        LambdaQueryWrapper<BaseRailwayManagement> lw = new LambdaQueryWrapper<BaseRailwayManagement>();
        if (!StringUtils.isBlank(baseRailwayManagementVo.getRailwayCode())) {
            lw.like(BaseRailwayManagement::getRailwayCode, "%" + baseRailwayManagementVo.getRailwayCode() + "%");
        }
        if (!ObjectUtils.isEmpty(baseRailwayManagementVo.getRailwayType())) {
            lw.eq(BaseRailwayManagement::getRailwayType, baseRailwayManagementVo.getRailwayType());
        }
        IPage<BaseRailwayManagement> page = baseRailwayManagementService.page(new Page<BaseRailwayManagement>(baseRailwayManagementVo.getPageNum(), baseRailwayManagementVo.getPageSize()), lw);
        return AjaxResult.success(page);
    }

    /**
     * 删除线路管理表信息
     *
     * @param lineIds
     * @return
     */
    @DeleteMapping("/{lineIds}")
    @ApiOperation("删除线路管理表信息")
    public AjaxResult removeLineManagement(@PathVariable List<Long> lineIds) {
        if (baseRailwayManagementService.removeByIds(lineIds)) {
            return AjaxResult.success();
        }
        return AjaxResult.error();
    }

    /**
     * 新增线路管理表信息
     *
     * @param baseRailwayManagement
     * @return
     */
    @PostMapping("/saveRailwayManagement")
    @ApiOperation("新增线路管理表信息")
    public AjaxResult saveLineManagement(@RequestBody BaseRailwayManagement baseRailwayManagement) {
        baseRailwayManagement.setCreateBy(getUsername());
        if (baseRailwayManagementService.save(baseRailwayManagement)) {
            return AjaxResult.success();
        }
        return AjaxResult.error();
    }

    /**
     * 修改线路管理表信息
     *
     * @param baseRailwayManagement
     * @return
     */
    @PutMapping("/editRailwayManagement")
    @ApiOperation("修改线路管理表信息")
    public AjaxResult editLineManagement(@RequestBody BaseRailwayManagement baseRailwayManagement) {
        baseRailwayManagement.setUpdateBy(getUsername());
        if (baseRailwayManagementService.updateById(baseRailwayManagement)) {
            return AjaxResult.success();
        }
        return AjaxResult.error();
    }

    @GetMapping(value = "/{id}")
    @ApiOperation("根据台账ID获取线路管理表详细信息")
    public AjaxResult getInfo(@PathVariable Long id) {
        return AjaxResult.success(baseRailwayManagementService.getById(id));
    }

    /**
     * 线路管理表信息导入
     *
     * @param file
     * @param updateSupport
     * @return
     * @throws Exception
     */
    @ApiOperation("线路管理表信息导入")
    @PostMapping("/importBaseLineManagement")
    public AjaxResult importBaseLineManagement(MultipartFile file, boolean updateSupport) throws Exception {
        ExcelUtil<BaseRailwayManagement> util = new ExcelUtil<BaseRailwayManagement>(BaseRailwayManagement.class);
        List<BaseRailwayManagement> AccountManageList = util.importExcel(file.getInputStream());
        String message = baseRailwayManagementService.importBaseLineManagement(AccountManageList, updateSupport);
        return AjaxResult.success(message);
    }

    /**
     * 导出线路管理表信息
     *
     * @param response
     */
    @ApiOperation("导出线路管理表信息")
    @PostMapping("/exportBaseLineManagement")
    public void exportBaseLineManagement(HttpServletResponse response, @RequestBody BaseRailwayManagementVo baseRailwayManagementVo) {
        LambdaQueryWrapper<BaseRailwayManagement> lw = new LambdaQueryWrapper<BaseRailwayManagement>();
        if (!StringUtils.isBlank(baseRailwayManagementVo.getRailwayCode())) {
            lw.like(BaseRailwayManagement::getRailwayCode, "%" + baseRailwayManagementVo.getRailwayCode() + "%");
        }
        if (!ObjectUtils.isEmpty(baseRailwayManagementVo.getRailwayType())) {
            lw.eq(BaseRailwayManagement::getRailwayType,  baseRailwayManagementVo.getRailwayType());
        }
        List<BaseRailwayManagement> list = baseRailwayManagementService.list(lw);
        ExcelUtil<BaseRailwayManagement> util = new ExcelUtil<>(BaseRailwayManagement.class);
        util.exportExcel(response, list, "线路台账数据");
    }

    @ApiOperation("线路管理表信息模板下载")
    @GetMapping("/downloaExcel")
    public void downloadZip(HttpServletResponse response) {
        try {
            InputStream resourceAsStream = this.getClass().getResourceAsStream("/template/planQuarter.xlsx");
            response.setContentType(MediaType.APPLICATION_OCTET_STREAM_VALUE);
            FileUtils.setAttachmentResponseHeader(response, "线路管理表信息导入模板.xlsx");
            FileUtils.writeBytesByInput(resourceAsStream, response.getOutputStream());
        } catch (Exception e) {
            log.error("下载文件失败", e);
        }
    }

    /**
     * 线路下拉
     */
    @ApiOperation(value = "线路下拉")
    @GetMapping("/query")
    public AjaxResult query() {
        return AjaxResult.success(baseRailwayManagementService.list());
    }


}

